==> autocomplete-editor-codemirror-1.0.4.tgz: package/lib/codeMirror.js <==
import { TypedEventEmitter } from '@syncot/events';
/**
 * Creates a new editor adapter for CodeMirror.
 */
export function createEditorAdapter(editor) {
    return new CodeMirrorEditorAdapter(editor);
}
class CodeMirrorEditorAdapter extends TypedEventEmitter {
    constructor(editor) {
        super();
        this.editor = editor;
        this.onKeyUp = (_editor, event) => {
            this.emit('keyUp', this, event);
        };
        this.onKeyDown = (_editor, event) => {
            this.emit('keyDown', this, event);
        };
        this.onInput = () => {
            this.emit('input', this);
        };
        this.onScroll = () => {
            this.emit('scroll', this);
        };
        this.onResize = () => {
            this.emit('resize', this);
        };
        this.onSelectionChange = () => {
            this.emit('selectionChange', this);
        };
        this.onKeyHandled = (_editor, name) => {
            // This is necessary because CodeMirror does not fire `inputRead` on Backspace and Delete.
            // See https://github.com/codemirror/CodeMirror/issues/3162#issuecomment-87582425
            if (name === 'Backspace' || name === 'Delete') {
                this.emit('input', this);
            }
        };
        this.editor.on('keyup', this.onKeyUp);
        this.editor.on('keydown', this.onKeyDown);
        this.editor.on('inputRead', this.onInput);
        this.editor.on('scroll', this.onScroll);
        this.editor.on('refresh', this.onResize);
        this.editor.on('cursorActivity', this.onSelectionChange);
        this.editor.on('keyHandled', this.onKeyHandled);
    }
    destroy() {
        this.editor.off('keyup', this.onKeyUp);
        this.editor.off('keydown', this.onKeyDown);
        this.editor.off('inputRead', this.onInput);
        this.editor.off('scroll', this.onScroll);
        this.editor.off('refresh', this.onResize);
        this.editor.off('cursorActivity', this.onSelectionChange);
        this.editor.off('keyHandled', this.onKeyHandled);
    }
    focus() {
        this.editor.focus();
    }
    get textBeforeCaret() {
        const doc = this.editor.getDoc();
        const end = doc.getCursor('head');
        const start = { line: end.line, ch: 0 };
        return doc.getRange(start, end);
    }
    set textBeforeCaret(text) {
        const doc = this.editor.getDoc();
        const end = doc.getCursor('head');
        const start = { line: end.line, ch: 0 };
        const newCursor = { line: end.line, ch: text.length };
        doc.replaceRange(text, start, end);
        doc.setCursor(newCursor);
    }
    get textAfterCaret() {
        const doc = this.editor.getDoc();
        const start = doc.getCursor('head');
        const end = { line: start.line, ch: Infinity };
        return doc.getRange(start, end);
    }
    set textAfterCaret(text) {
        const doc = this.editor.getDoc();
        const start = doc.getCursor('head');
        const end = { line: start.line, ch: Infinity };
        const newCursor = start;
        doc.replaceRange(text, start, end);
        doc.setCursor(newCursor);
    }
    get caretPosition() {
        const doc = this.editor.getDoc();
        const caret = doc.getCursor('head');
        const position = this.editor.cursorCoords(caret, 'window');
        return {
            bottom: position.bottom,
            left: position.left,
            right: position.left,
            top: position.top,
        };
    }
    get editorPosition() {
        const position = this.editor.getWrapperElement().getBoundingClientRect();
        return {
            bottom: position.bottom,
            left: position.left,
            right: position.right,
            top: position.top,
        };
    }
}

==> autocomplete-editor-codemirror-1.1.0.tgz: package/lib/codeMirror.js <==
import { TypedEventEmitter } from '@syncot/events';
/**
 * Creates a new editor adapter for CodeMirror.
 */
export function createEditorAdapter(editor) {
    return new CodeMirrorEditorAdapter(editor);
}
class CodeMirrorEditorAdapter extends TypedEventEmitter {
    constructor(editor) {
        super();
        this.editor = editor;
        this.onKeyUp = (_editor, event) => {
            this.emit('keyUp', this, event);
        };
        this.onKeyDown = (_editor, event) => {
            this.emit('keyDown', this, event);
        };
        this.onInput = () => {
            this.emit('input', this);
        };
        this.onScroll = () => {
            this.emit('scroll', this);
        };
        this.onResize = () => {
            this.emit('resize', this);
        };
        this.onSelectionChange = () => {
            this.emit('selectionChange', this);
        };
        this.onKeyHandled = (_editor, name) => {
            // This is necessary because CodeMirror does not fire `inputRead` on Backspace and Delete.
            // See https://github.com/codemirror/CodeMirror/issues/3162#issuecomment-87582425
            if (name === 'Backspace' || name === 'Delete') {
                this.emit('input', this);
            }
        };
        this.editor.on('keyup', this.onKeyUp);
        this.editor.on('keydown', this.onKeyDown);
        this.editor.on('inputRead', this.onInput);
        this.editor.on('scroll', this.onScroll);
        this.editor.on('refresh', this.onResize);
        this.editor.on('cursorActivity', this.onSelectionChange);
        this.editor.on('keyHandled', this.onKeyHandled);
    }
    destroy() {
        this.editor.off('keyup', this.onKeyUp);
        this.editor.off('keydown', this.onKeyDown);
        this.editor.off('inputRead', this.onInput);
        this.editor.off('scroll', this.onScroll);
        this.editor.off('refresh', this.onResize);
        this.editor.off('cursorActivity', this.onSelectionChange);
        this.editor.off('keyHandled', this.onKeyHandled);
    }
    focus() {
        this.editor.focus();
    }
    getCaretPosition(offset = 0) {
        const doc = this.editor.getDoc();
        const caret = doc.getCursor('head');
        const offsetCaret = {
            ch: caret.ch + offset,
            line: caret.line,
            sticky: caret.sticky,
        };
        const position = this.editor.cursorCoords(offsetCaret, 'window');
        return {
            bottom: position.bottom,
            left: position.left,
            right: position.left,
            top: position.top,
        };
    }
    get textBeforeCaret() {
        const doc = this.editor.getDoc();
        const end = doc.getCursor('head');
        const start = { line: end.line, ch: 0 };
        return doc.getRange(start, end);
    }
    set textBeforeCaret(text) {
        const doc = this.editor.getDoc();
        const end = doc.getCursor('head');
        const start = { line: end.line, ch: 0 };
        const newCursor = { line: end.line, ch: text.length };
        doc.replaceRange(text, start, end);
        doc.setCursor(newCursor);
    }
    get textAfterCaret() {
        const doc = this.editor.getDoc();
        const start = doc.getCursor('head');
        const end = { line: start.line, ch: Infinity };
        return doc.getRange(start, end);
    }
    set textAfterCaret(text) {
        const doc = this.editor.getDoc();
        const start = doc.getCursor('head');
        const end = { line: start.line, ch: Infinity };
        const newCursor = start;
        doc.replaceRange(text, start, end);
        doc.setCursor(newCursor);
    }
    get caretPosition() {
        return this.getCaretPosition();
    }
    get editorPosition() {
        const position = this.editor.getWrapperElement().getBoundingClientRect();
        return {
            bottom: position.bottom,
            left: position.left,
            right: position.right,
            top: position.top,
        };
    }
}
